#! /bin/sh
#
# @(#)41  1.12  src/oss/common/watchdog/ffdcapture.sh, oss.common.src, oss600, 060310a 3/7/06 14:01:14
#
# 5698-PDO
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2000,2006. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#set -x

####################################################################
####################################################################
#
# First Failure Data Capture script to copy useful data for 
# diagnosing potential AMOS problems.
# This script will be called by the pdoswdd, and is NOT
# intended to be run by a user.
#
####################################################################
####################################################################

DATADIR=/var/pdos/ffdc
KAZNFILE=$DATADIR/kazntrace.out
KAZN="/opt/pdos/sbin/kazntrace"

CP='/bin/cp -p '
MV=/bin/mv
LN='/bin/ln -s -f '
COMPRESS=/bin/compress
FILE=/usr/bin/file

####################################################################
#
# This unit will try to copy a group of files to our storage area
# $1 is a directory and all files in the directory aer copied.
# 
#
####################################################################
mcopy() {
   if [ -d ${1} ]; then
       ${CP} ${1}/* ${DATADIR}
   fi
}
####################################################################
#
# This unit will try to create a soft link from our storage
# area to a file
# $1 is a fully qualified file name
# $2 is the target file name, DATADIR will be prepended
# The link will only be done if the file is a regular file (-f)
# and any existing links will be overwritten.
#
####################################################################
link() {
   if [ -f ${1} ]; then
       ${LN} ${1} ${DATADIR}/${2}
   fi
}

####################################################################
#
# This unit will try to create a soft link from our storage
# area (/var/pdos/{daemon}/{core file} to the DATADIR (ffdc directory)
# Links are made for all the core files produced in the last 5 minutes
# $1 is the daemon directory e.g. /var/pdos/pdosd
# $2 is the prefix to use for the soft link file name being created.
####################################################################

link_linux_cores() {
   COUNT=0
   CORES=`find $1 -type f -mmin -5 -print`
   for i in ${CORES}
   do
        NAME=`${FILE} ${i}  | grep "core" | awk -F ':' '{print $1}'`
        if [  "foo"${NAME} != "foo" ]
           then
                ${LN} ${NAME} ${DATADIR}/${2}.${COUNT}
                COUNT=`expr ${COUNT} + 1`
        fi
   done

}

####################################################################
#
# This unit will try to copy a file to our storage area
# $1 is the fully qualified file name
# $2 is the target file name, DATADIR will be prepended
#
####################################################################
copy() {
   if [ -f ${1} ]; then
       ${CP} ${1} ${DATADIR}/${2}
   fi
}
####################################################################
#
# This unit will try to move a file to our storage area
# $1 is the fully qualified file name
# $2 is the target file name, DATADIR will be prepended
#
####################################################################
move() {
   if [ -f ${1} ]; then
       ${MV} ${1} ${DATADIR}/${2}
   fi
}

####################################################################
#
# This unit is try to move a file to our storage area
# and compress it.
# $1 is the fully qualified file name
# $2 is the target file name, DATADIR will be prepended
#
####################################################################
move_and_compress() {
    if [ -f ${1} ]; then
       ${MV} ${1} ${DATADIR}/${2}
       ${COMPRESS} ${DATADIR}/${2}
    fi
}
####################################################################
#
# This unit will try to move the core file to a file name core.1
# $1 is the directory where the core file is
# if a filenamed core.1 exists in the directory $1, it will be renamed
# to core.2
# This way , two copies of core files will be saved.
#
####################################################################
move_core() {
   if [ -f ${1}/core ]; then
       if [ -f ${1}/core.1 ]; then
          ${MV} ${1}/core.1 ${1}/core.2
       fi
       ${MV} ${1}/core ${1}/core.1
   fi
}

####################################################################
#
# This unit is to capture the kazntrace result.
#
####################################################################
getKAZNtrace() {
    ${KAZN} > ${KAZNFILE}
}


####################################################################

 #####  #######    #    ######  #######
#     #    #      # #   #     #    #
#          #     #   #  #     #    #
 #####     #    #     # ######     #
      #    #    ####### #   #      #
#     #    #    #     # #    #     #
 #####     #    #     # #     #    #

#     #    #      ###   #     #
##   ##   # #      #    ##    #
# # # #  #   #     #    # #   #
#  #  # #     #    #    #  #  #
#     # #######    #    #   # #
#     # #     #    #    #    ##
#     # #     #   ###   #     #

####################################################################
####################################################################
####################################################################

PROGRAM=`basename $0`
getKAZNtrace

OS_NAME=`uname`

case $OS_NAME in
    Linux)
	
	link_linux_cores /var/pdos/pdosd	core.pdosd
	link_linux_cores /var/pdos/pdoswdd	core.pdoswdd
	link_linux_cores /var/pdos/pdosauditd 	core.pdosauditd
	link_linux_cores /var/pdos/pdoslrd	core.pdoslrd
	link_linux_cores /var/pdos/lpm		core.pdoslpmd
	;;
    *)
	move_core /var/pdos/pdosd
	move_core /var/pdos/pdoswdd
	move_core /var/pdos/pdosauditd
	move_core /var/pdos/pdoslrd
	move_core /var/pdos/lpm
	
	link /var/pdos/pdosd/core.1 core.pdosd
	link /var/pdos/pdoswdd/core.1 core.pdoswdd
	link /var/pdos/pdosauditd/core.1 core.pdosauditd
	link /var/pdos/pdoslrd/core.1 core.pdoslrd
	link /var/pdos/lpm/core.1 core.pdoslpmd
	;;
esac


mcopy /var/pdos/log
mcopy /var/pdos/tracelogs

exit 0
